[−][src]Function mdbook_linkcheck::load_files_into_memory
pub fn load_files_into_memory(book: &Book, dest: &mut Files) -> Vec<FileId>
A helper for reading the chapters of a [Book] into memory.
pub fn load_files_into_memory(book: &Book, dest: &mut Files) -> Vec<FileId>
A helper for reading the chapters of a [Book] into memory.