[−][src]Struct mdbook_linkcheck::Config
The configuration options available with this backend.
Fields
follow_web_links: boolIf a link on the internet is encountered, should we still try to check
if it's valid? Defaults to false because this has a big performance
impact.
traverse_parent_directories: boolAre we allowed to link to files outside of the book's source directory?
exclude: Vec<Regex>A list of URL patterns to ignore when checking remote links.
user_agent: StringThe user-agent used whenever any web requests are made.
cache_timeout: u64The number of seconds a cached result is valid for.
Methods
impl Config[src]
pub const DEFAULT_CACHE_TIMEOUT: Duration[src]
The default cache timeout (around 12 hours).
pub const DEFAULT_USER_AGENT: &'static str[src]
The default user-agent.
pub fn should_skip(&self, link: &str) -> bool[src]
Checks [Config::exclude] to see if the provided link should be
skipped.